summaryrefslogtreecommitdiff
path: root/plugins/python/python.plugin.zsh
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/python/python.plugin.zsh')
-rw-r--r--plugins/python/python.plugin.zsh3
1 files changed, 2 insertions, 1 deletions
diff --git a/plugins/python/python.plugin.zsh b/plugins/python/python.plugin.zsh
index a10c06fd3..f754ea261 100644
--- a/plugins/python/python.plugin.zsh
+++ b/plugins/python/python.plugin.zsh
@@ -1,12 +1,13 @@
# Find python file
alias pyfind='find . -name "*.py"'
# Remove python compiled byte-code in either current directory or in a
# list of specified directories
function pyclean() {
ZSH_PYCLEAN_PLACES=${*:-'.'}
find ${ZSH_PYCLEAN_PLACES} -type f -name "*.py[co]" -delete
find ${ZSH_PYCLEAN_PLACES} -type d -name "__pycache__" -delete
+ find ${ZSH_PYCLEAN_PLACES} -type d -name ".mypy_cache" -delete
}
# Grep among .py files
@@ -1,12 +1,13 @@
# Find python file
alias pyfind='find . -name "*.py"'
-# Remove python compiled byte-code in either current directory or in a
+# Remove python compiled byte-code and mypy cache in either current directory or in a
# list of specified directories
function pyclean() {